unit QRExpert;

{ Before open the QRXMAIN form, you MUST install the components in QRXUTIL.PAS
  Unit. Otherwise you'll receive the message: Class 'TTableListBox' not found. }

interface

uses Forms,
  WinTypes,
  WinProcs,
  Dialogs,
  ExptIntf,
  ToolIntf,
  VirtIntf,
  SysUtils,
  QRXMain,
  QRXUtil;

type
  TQRStandardExpert = class(TIExpert)
{$IfDef Win32}
    function GetName: AnsiString; override;
    function GetComment: AnsiString; override;
    function GetMenuText: AnsiString; override;
    function GetIDString: AnsiString; override;
    function GetGlyph: HICON; override;
    function GetAuthor:AnsiString; override;
    function GetPage:AnsiString; override;
{$Else}
    function GetName: string; override;
    function GetComment: string; override;
    function GetMenuText: string; override;
    function GetIDString: string; override;
    function GetGlyph: HBITMAP; override;
{$Endif}
    function GetStyle: TExpertStyle; override; { Style }
    function GetState: TExpertState; override;
    procedure Execute; override; { Launch the Expert }
  end;

  TQRFormExpert = class(TQRStandardExpert)
{$IfDef Win32}
    function GetComment: AnsiString; override;
    function GetIDString: AnsiString; override;
    function GetGlyph: HICON; override;
{$Else}
    function GetComment: string; override;
    function GetIDString: string; override;
    function GetGlyph: HBITMAP; override;
{$Endif}
    function GetStyle: TExpertStyle; override; { Style }
  end;

procedure Register;

implementation

{$IfNDef Win32}
{$R QRX16.RES}
{$Else}
{$R QRX32.RES}
{$EndIf}

procedure Register;
begin
  RegisterLibraryExpert(TQRFormExpert.Create);
  RegisterLibraryExpert(TQRStandardExpert.Create);
end;

procedure HandleException;
begin
  ToolServices.RaiseException(ReleaseException);
end;

function TQRStandardExpert.GetName: {$IfDef Win32} AnsiString; {$Else} String; {$EndIf}
begin
  try
    Result := 'QuickReport Expert';
  except
    HandleException;
  end;
end;

function TQRStandardExpert.GetComment:{$IfDef Win32} AnsiString; {$Else} String; {$EndIf}
begin
  Result := ''
end;

function TQRStandardExpert.GetMenuText:{$IfDef Win32} AnsiString; {$Else} String; {$EndIf}
begin
  try
    Result := 'QuickReport Expert...';
  except
    HandleException;
  end;
end;

function TQRStandardExpert.GetIDString: {$IfDef Win32} AnsiString; {$Else} String; {$EndIf}
begin
  try
    Result := 'Schmidt.QuickReportStandardExpert'
  except
    HandleException;
  end;
end;

function TQRStandardExpert.GetGlyph: {$IfDef Win32} HICON; {$Else} HBITMAP; {$EndIf}
begin
  Result := 0; { not need for esStandard }
end;

{$IfDef Win32}
function TQRStandardExpert.GetAuthor:AnsiString;
begin
  try
    Result := 'Moacir Schmidt';
  except
    HandleException;
  end;
end;

function TQRStandardExpert.GetPage:AnsiString;
begin
  try
    Result := 'Forms';
  except
    HandleException;
  end;
end;
{$EndIf}

function TQRStandardExpert.GetStyle:TExpertStyle;
begin
  try
    Result := esStandard;
  except
    HandleException;
  end;
end;

function TQRStandardExpert.GetState: TExpertState;
begin
  try
    Result := [esEnabled];
  except
    HandleException;
  end;
end;

procedure TQRStandardExpert.Execute;
begin
  try
    QuickRepExpert(ToolServices);
  except
    HandleException;
  end;
end;

function TQRFormExpert.GetComment:{$IfDef Win32} AnsiString; {$Else} String; {$EndIf}
begin
  try
    Result := 'Creates a new QuickReport form';
  except
    HandleException;
  end;
end;

function TQRFormExpert.GetIDString: {$IfDef Win32} AnsiString; {$Else} String; {$EndIf}
begin
  try
    Result := 'Schmidt.QuickReportFormExpert'
  except
    HandleException;
  end;
end;

function TQRFormExpert.GetGlyph: {$IfDef Win32} HICON; {$Else} HBITMAP; {$EndIf}
begin
{$IfDef Win32}
  try
    Result := LoadIcon(HInstance, 'QRX_ICON');
  except
    HandleException;
  end;
{$Else}
  try
    Result := LoadBitMap(HInstance, 'QRX_BITMAP');
  except
    HandleException;
  end;
{$EndIf}
end;

function TQRFormExpert.GetStyle:TExpertStyle;
begin
  try
    Result := esForm;
  except
    HandleException;
  end;
end;

begin
end.
